BitBar Plugin
=============

A copy of the latest stable version of the BitBar plugin for ``mpm`` is always
`available on BitBar website
<https://getbitbar.com/plugins/Dev/MetaPackageManager/meta_package_manager.7h.py>`_
and `plugin repository
<https://github.com/matryer/bitbar-plugins/tree/master/Dev/MetaPackageManager>`_.

.. image:: https://raw.githubusercontent.com/kdeldycke/meta-package-manager/develop/screenshot.png
    :alt: Bitbar plugin screenshot.
    :align: left


Development workflow
--------------------

Active development of the plugin is happening here, as a side-project of
``mpm`` itself.

Releases of the plugin is synchronized with the package. Both share the exact
same version to simplify management. This explain why the plugin could appears
jumpimg ahead of a couple of major/minor version while providing tiny or no
changes at all.

A release is ready when both the package and the plugin reach a stable state.

If the plugin has been changed between releases, a `copy of the plugin is
pushed
<https://github.com/matryer/bitbar-plugins/pulls?q=is%3Apr%20%22Meta%20Package%20Manager%22>`_
to the `official BitBar plugin repository
<https://github.com/matryer/bitbar-plugins/tree/master/Dev/MetaPackageManager>`_.
